/*==============================================================================

       cpaRadioButton - overridden class for CRadioButton to add group-awareness

       Copyright  2001 Pankhurst Algorithmics - All Rights Reserved
       visit www.ebmDevMag.com for permissions/restrictions on use

==============================================================================*/
#include "gui.h"

#include "pa_radio.h"
//------------------------------------------------------------------------------
/*static*/ cpaRadioButton *cpaRadioButton::s_firstObject;
//------------------------------------------------------------------------------
cpaRadioButton::cpaRadioButton(int id,int width,int height,const char *caption,int groupId)
 : CRadioButton(id,width,height,caption),
   m_tag(-1),
   m_groupId(groupId)
{
  // add entry to list - simply place at beginning, and move curr. pointer to us
  m_nextObject =s_firstObject;
  s_firstObject=this;
}
//------------------------------------------------------------------------------
cpaRadioButton::~cpaRadioButton(void)
{
  // remove itself from chain - walk along list, looking for us, then swap out
  cpaRadioButton *ptr=s_firstObject;
  if ( this==ptr ) // we are first entry?
    s_firstObject=m_nextObject; // our link is removed
  else // unlink from one of remaining objects - walk list
  {
    while ( NULL!=ptr )
    {
      if ( this == ptr->m_nextObject )
      {
        ptr->m_nextObject=m_nextObject;
        break;
      }
      ptr=ptr->m_nextObject;
    }
  }
}
//------------------------------------------------------------------------------
void cpaRadioButton::SetDownStatus(BOOL status)
{
  if (false==status) // trying to 'unselect'? don't allow that
    return;
  if ( m_groupId>=0 ) // valid group id - look for and turn off companions
  {
    // walk list, turning off all those with identical ids
    cpaRadioButton*ptr=s_firstObject;
    while ( NULL!=ptr )
    {
      // check if from our group and down - if so, set up
      if ( ptr->m_groupId==m_groupId && ptr->GetDownStatus() )
        ptr->CRadioButton::SetDownStatus(false);
      ptr=ptr->m_nextObject;
    }
  }
  CRadioButton::SetDownStatus(status);
}
//------------------------------------------------------------------------------
/*static*/cpaRadioButton *cpaRadioButton::GetGroupDownButton(long groupID)
{
  // return 'down' button ptr for down button in group
  if (groupID<0)
    return 0; // only works with valid group ids
  cpaRadioButton*ptr=s_firstObject;
  while ( NULL!=ptr )
  {
    if ( ptr->m_groupId==groupID && ptr->GetDownStatus() ) // ours and down?
      return ptr;
    ptr=ptr->m_nextObject;
  }
  return 0; // if nothing down, return null
}
//------------------------------------------------------------------------------
S32 cpaRadioButton::MsgHandler(MSG_TYPE type, CViewable *from, S32 data)
{
	switch (type)
  {
    case MSG_PEN_DOWN:
    case MSG_PEN_DOUBLECLICK:
      SetDownStatus(true);
      // send message to parent
      GetParent()->MsgHandler( MSG_BUTTON_SELECT, this, true);
      break;
    case MSG_PEN_UP:
    case MSG_PEN_TRACK:
      // ignore these
      break;
    default: // all others messages processed by CRadioButton class as usual
      return CRadioButton::MsgHandler( type, from, data );
	}
	return 1;
}
//------------------------------------------------------------------------------

